Skip to contents

This dataset contains the population denominators used to create the Indices of Deprivation 2025 (IoD25). The populations are derived from the mid-2022 ONS population estimates.

Usage

population

Format

A tibble with 135,020 rows and 6 variables:

lsoa_code

Identifiers of 2021 Census Geography boundaries (Lower Layer Super Output Areas)

lsoa_name

Names of 2021 Census Geography boundaries (Lower Layer Super Output Areas)

lad_code

Identifiers for local authority districts (LAD) and unitary authorities (UA) in the United Kingdom as at 2024

lad_name

Names for local authority districts (LAD) and unitary authorities (UA) in the United Kingdom as at 2024

population_group

Population group

population

Population

Ministry of Housing, Communities & Local Government (MHCLG), Indices of Multiple Deprivation 2025, (2025). Available at: https://open-data.communities.gov.uk/datasets/indices-of-deprivation-2025/ (Accessed: 25 May 2025). Licensed under the Open Government Licence v3.0.

Details

The data has been extracted from the All scores, ranks and deciles source file and transformed into into a long ('tidy') format.